Process `input` depth texture and generate an ambient occlusion overlay in `output`, input and output must be of the same size.

Use [CreateSAO] to create a [SAO] object and [DestroySAO] to destroy its internal resources after usage.